@@ -226,18 +226,14 @@ class VirtualDevice(QObject):
 
     @property
     def frequency(self):
-        if self.backend == Backends.grc:
-            return self.__dev.freq
-        elif self.backend == Backends.native:
+        if self.backend in (Backends.grc, Backends.native):
             return self.__dev.frequency
         else:
             raise ValueError("Unsupported Backend")
 
     @frequency.setter
     def frequency(self, value):
-        if self.backend == Backends.grc:
-            self.__dev.freq = value
-        elif self.backend == Backends.native:
+        if self.backend in (Backends.grc, Backends.native):
             self.__dev.frequency = value
         elif self.backend == Backends.network:
             pass
@@ -400,6 +396,18 @@ class VirtualDevice(QObject):
         else:
             raise ValueError("Unsupported Backend")
 
+    @property
+    def subdevice(self):
+        if hasattr(self.__dev, "subdevice"):
+            return self.__dev.subdevice
+        else:
+            return None
+
+    @subdevice.setter
+    def subdevice(self, value: str):
+        if hasattr(self.__dev, "subdevice"):
+            self.__dev.subdevice = value
+
     @property
     def ip(self):
         if self.backend == Backends.grc:
